==> apache-devlake-0.17.0-incubating-src.tar.gz: apache-devlake-0.17.0-incubating-src/backend/plugins/trello/models/migrationscripts/20230305_add_init_tables.go <==
/*
Licensed to the Apache Software Foundation (ASF) under one or more
contributor license agreements.  See the NOTICE file distributed with
this work for additional information regarding copyright ownership.
The ASF licenses this file to You under the Apache License, Version 2.0
(the "License"); you may not use this file except in compliance with
the License.  You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package migrationscripts

import (
	"github.com/apache/incubator-devlake/core/context"
	"github.com/apache/incubator-devlake/core/errors"
	"github.com/apache/incubator-devlake/helpers/migrationhelper"
	"github.com/apache/incubator-devlake/plugins/trello/models"
)

type addInitTables struct{}

func (*addInitTables) Up(basicRes context.BasicRes) errors.Error {
	return migrationhelper.AutoMigrateTables(
		basicRes,
		&models.TrelloConnection{},
		&models.TrelloBoard{},
		&models.TrelloList{},
		&models.TrelloCard{},
		&models.TrelloLabel{},
		&models.TrelloMember{},
		&models.TrelloCheckItem{},
		&models.TrelloTransformationRule{},
	)
}

func (*addInitTables) Version() uint64 {
	return 20230305000014
}

func (*addInitTables) Name() string {
	return "trello init schemas"
}

==> apache-devlake-1.0.2-incubating-src.tar.gz: apache-devlake-1.0.2-incubating-src/backend/plugins/trello/models/migrationscripts/20230305_add_init_tables.go <==
/*
Licensed to the Apache Software Foundation (ASF) under one or more
contributor license agreements.  See the NOTICE file distributed with
this work for additional information regarding copyright ownership.
The ASF licenses this file to You under the Apache License, Version 2.0
(the "License"); you may not use this file except in compliance with
the License.  You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package migrationscripts

import (
	"github.com/apache/incubator-devlake/core/context"
	"github.com/apache/incubator-devlake/core/errors"
	"github.com/apache/incubator-devlake/helpers/migrationhelper"
	"github.com/apache/incubator-devlake/plugins/trello/models/migrationscripts/archived"
)

type addInitTables struct{}

func (*addInitTables) Up(basicRes context.BasicRes) errors.Error {
	return migrationhelper.AutoMigrateTables(
		basicRes,
		&archived.TrelloConnection{},
		&archived.TrelloBoard{},
		&archived.TrelloList{},
		&archived.TrelloCard{},
		&archived.TrelloLabel{},
		&archived.TrelloMember{},
		&archived.TrelloCheckItem{},
		&archived.TrelloTransformationRule{},
	)
}

func (*addInitTables) Version() uint64 {
	return 20230305000014
}

func (*addInitTables) Name() string {
	return "trello init schemas"
}
